.. _Python: https://www.python.org/
.. _Click: https://click.palletsprojects.com
.. _Python Slugify: https://github.com/un33k/python-slugify
.. _Unidecode: https://github.com/avian2/unidecode/tree/master/unidecode

=====
Deovi
=====

An utility to rename files using tasks from a job.

Links
*****

* Read the documentation on `Read the docs <https://deovi.readthedocs.io/>`_;
* Download its `PyPi package <https://pypi.python.org/pypi/deovi>`_;
* Clone it on its `Github repository <https://github.com/sveetch/deovi>`_;

Dependancies
************

* `Python`_>=3.6;
* `Click`_>=8.0;
* `Python Slugify`_>= 5.0.0;
* `Unidecode`_;
